import type { OpenId4VcSiopAcceptAuthorizationRequestOptions, OpenId4VcSiopFetchEntityConfigurationOptions, OpenId4VcSiopResolveAuthorizationRequestOptions, OpenId4VcSiopResolvedAuthorizationRequest, OpenId4VcSiopResolveTrustChainsOptions } from './OpenId4vcSiopHolderServiceOptions';
import type { AgentContext } from '@credo-ts/core';
import type { AuthorizationResponsePayload } from '@sphereon/did-auth-siop';
import { DifPresentationExchangeService } from '@credo-ts/core';
import { fetchEntityConfiguration as federationFetchEntityConfiguration } from '@openid-federation/core';
export declare class OpenId4VcSiopHolderService {
    private presentationExchangeService;
    constructor(presentationExchangeService: DifPresentationExchangeService);
    resolveAuthorizationRequest(agentContext: AgentContext, requestJwtOrUri: string, options?: OpenId4VcSiopResolveAuthorizationRequestOptions): Promise<OpenId4VcSiopResolvedAuthorizationRequest>;
    acceptAuthorizationRequest(agentContext: AgentContext, options: OpenId4VcSiopAcceptAuthorizationRequestOptions): Promise<{
        readonly ok: false;
        readonly serverResponse: {
            readonly status: number;
            readonly body: string | Record<string, unknown> | null;
        };
        readonly submittedResponse: AuthorizationResponsePayload;
        readonly redirectUri?: undefined;
        readonly presentationDuringIssuanceSession?: undefined;
    } | {
        readonly ok: true;
        readonly serverResponse: {
            readonly status: number;
            readonly body: Record<string, unknown>;
        };
        readonly submittedResponse: AuthorizationResponsePayload;
        readonly redirectUri: string | undefined;
        readonly presentationDuringIssuanceSession: string | undefined;
    }>;
    private getOpenIdProvider;
    private getOpenIdTokenIssuerFromVerifiablePresentation;
    private assertValidTokenIssuer;
    private encryptJarmResponse;
    resolveOpenIdFederationChains(agentContext: AgentContext, options: OpenId4VcSiopResolveTrustChainsOptions): Promise<{
        chain: Awaited<ReturnType<typeof import("@openid-federation/core").fetchEntityStatementChain>>;
        leafEntityConfiguration: Awaited<ReturnType<typeof federationFetchEntityConfiguration>>;
        trustAnchorEntityConfiguration: Awaited<ReturnType<typeof federationFetchEntityConfiguration>>;
    }[]>;
    fetchOpenIdFederationEntityConfiguration(agentContext: AgentContext, options: OpenId4VcSiopFetchEntityConfigurationOptions): Promise<{
        sub: string;
        jwks: {
            keys: import("zod").objectOutputType<{
                kty: import("zod").ZodString;
                kid: import("zod").ZodString;
                use: import("zod").ZodOptional<import("zod").ZodString>;
                key_ops: import("zod").ZodOptional<import("zod").ZodArray<import("zod").ZodString, "many">>;
                alg: import("zod").ZodOptional<import("zod").ZodString>;
                x5u: import("zod").ZodOptional<import("zod").ZodString>;
                x5c: import("zod").ZodOptional<import("zod").ZodString>;
                x5t: import("zod").ZodOptional<import("zod").ZodString>;
                "x5t#S256": import("zod").ZodOptional<import("zod").ZodString>;
            }, import("zod").ZodTypeAny, "passthrough">[];
        };
        iss: string;
        iat: Date;
        exp: Date;
        authority_hints?: string[] | undefined;
        metadata?: {
            federation_entity?: {
                jwks?: {
                    keys: import("zod").objectOutputType<{
                        kty: import("zod").ZodString;
                        kid: import("zod").ZodString;
                        use: import("zod").ZodOptional<import("zod").ZodString>;
                        key_ops: import("zod").ZodOptional<import("zod").ZodArray<import("zod").ZodString, "many">>;
                        alg: import("zod").ZodOptional<import("zod").ZodString>;
                        x5u: import("zod").ZodOptional<import("zod").ZodString>;
                        x5c: import("zod").ZodOptional<import("zod").ZodString>;
                        x5t: import("zod").ZodOptional<import("zod").ZodString>;
                        "x5t#S256": import("zod").ZodOptional<import("zod").ZodString>;
                    }, import("zod").ZodTypeAny, "passthrough">[];
                } | undefined;
                signed_jwks_uri?: string | undefined;
                jwks_uri?: string | undefined;
                organization_name?: string | undefined;
                contacts?: string[] | undefined;
                logo_uri?: string | undefined;
                policy_uri?: string | undefined;
                homepage_uri?: string | undefined;
                federation_fetch_endpoint?: string | undefined;
                federation_list_endpoint?: string | undefined;
                federation_resolve_endpoint?: string | undefined;
                federation_trust_mark_status_endpoint?: string | undefined;
                federation_trust_mark_list_endpoint?: string | undefined;
                federation_trust_mark_endpoint?: string | undefined;
                federation_historical_keys_endpoint?: string | undefined;
            } | undefined;
            oauth_client?: {
                [x: string]: any;
            } | undefined;
            oauth_resource?: {
                [x: string]: any;
            } | undefined;
            openid_provider?: {
                client_registration_types_supported: ("automatic" | "explicit")[];
                jwks?: {
                    keys: import("zod").objectOutputType<{
                        kty: import("zod").ZodString;
                        kid: import("zod").ZodString;
                        use: import("zod").ZodOptional<import("zod").ZodString>;
                        key_ops: import("zod").ZodOptional<import("zod").ZodArray<import("zod").ZodString, "many">>;
                        alg: import("zod").ZodOptional<import("zod").ZodString>;
                        x5u: import("zod").ZodOptional<import("zod").ZodString>;
                        x5c: import("zod").ZodOptional<import("zod").ZodString>;
                        x5t: import("zod").ZodOptional<import("zod").ZodString>;
                        "x5t#S256": import("zod").ZodOptional<import("zod").ZodString>;
                    }, import("zod").ZodTypeAny, "passthrough">[];
                } | undefined;
                signed_jwks_uri?: string | undefined;
                jwks_uri?: string | undefined;
                organization_name?: string | undefined;
                contacts?: string[] | undefined;
                logo_uri?: string | undefined;
                policy_uri?: string | undefined;
                homepage_uri?: string | undefined;
                federation_registration_endpoint?: string | undefined;
                request_authentication_methods_supported?: {
                    authorization_endpoint?: string[] | undefined;
                    pushed_authorization_request_endpoint?: string[] | undefined;
                } | undefined;
                request_authentication_signing_alg_values_supported?: string[] | undefined;
            } | undefined;
            openid_relying_party?: {
                client_registration_types: ("automatic" | "explicit")[];
                jwks?: {
                    keys: import("zod").objectOutputType<{
                        kty: import("zod").ZodString;
                        kid: import("zod").ZodString;
                        use: import("zod").ZodOptional<import("zod").ZodString>;
                        key_ops: import("zod").ZodOptional<import("zod").ZodArray<import("zod").ZodString, "many">>;
                        alg: import("zod").ZodOptional<import("zod").ZodString>;
                        x5u: import("zod").ZodOptional<import("zod").ZodString>;
                        x5c: import("zod").ZodOptional<import("zod").ZodString>;
                        x5t: import("zod").ZodOptional<import("zod").ZodString>;
                        "x5t#S256": import("zod").ZodOptional<import("zod").ZodString>;
                    }, import("zod").ZodTypeAny, "passthrough">[];
                } | undefined;
                signed_jwks_uri?: string | undefined;
                jwks_uri?: string | undefined;
                organization_name?: string | undefined;
                contacts?: string[] | undefined;
                logo_uri?: string | undefined;
                policy_uri?: string | undefined;
                homepage_uri?: string | undefined;
            } | undefined;
            oauth_authorization_server?: {
                [x: string]: any;
            } | undefined;
        } | undefined;
        metadata_policy?: ({
            [x: string]: any;
        } & {
            [k: string]: unknown;
        }) | undefined;
        constraints?: {
            max_path_length?: number | undefined;
            naming_constraints?: {
                permitted?: string[] | undefined;
                excluded?: string[] | undefined;
            } | undefined;
            allowed_entity_types?: string[] | undefined;
        } | undefined;
        crit?: string[] | undefined;
        metadata_policy_crit?: string[] | undefined;
        trust_marks?: {
            id: string;
            trust_mark: {
                header: Record<string | number, unknown>;
                claims: {
                    sub: string;
                    iss: string;
                    id: string;
                    iat: Date;
                    exp?: Date | undefined;
                    ref?: string | undefined;
                };
                signature: Uint8Array;
            };
        }[] | undefined;
        trust_mark_issuers?: Record<string, string[]> | undefined;
        trust_mark_owners?: Record<string, {
            sub: string;
            jwks: {
                keys: import("zod").objectOutputType<{
                    kty: import("zod").ZodString;
                    kid: import("zod").ZodString;
                    use: import("zod").ZodOptional<import("zod").ZodString>;
                    key_ops: import("zod").ZodOptional<import("zod").ZodArray<import("zod").ZodString, "many">>;
                    alg: import("zod").ZodOptional<import("zod").ZodString>;
                    x5u: import("zod").ZodOptional<import("zod").ZodString>;
                    x5c: import("zod").ZodOptional<import("zod").ZodString>;
                    x5t: import("zod").ZodOptional<import("zod").ZodString>;
                    "x5t#S256": import("zod").ZodOptional<import("zod").ZodString>;
                }, import("zod").ZodTypeAny, "passthrough">[];
            };
        }> | undefined;
        source_endpoint?: string | undefined;
    }>;
}
